@@ -97,7 +97,7 @@ def main_load(
 
 
 def main_transformation(
-    mappingfile=None, mainsheet=None, stagingdata=None, outputfile=None
+    mappingfile=None, mainsheet=None, stagingdata=None, outputfile=None, url=None, ionfile=None,
 ):
 
     if mappingfile is None:
@@ -114,7 +114,7 @@ def main_transformation(
 
     try:
         return parallelize_tranformation(
-            mappingfile, mainsheet, stagingdata, outputfile
+            mappingfile, mainsheet, stagingdata, outputfile, url, ionfile
         )
     except Exception as ex:
         logger.exception(ex)
